from .mizu import Mizu as _Mizu
from .options import Options
from asyncio import AbstractEventLoop
from typing import Optional


class Mizu:
    """
    Markdown parser.

    Args:
        options (Options): Options for parser.
        loop (AbstractEventLoop): Event loop
    """
    def __init__(
        self, options: Options = Options(),
        loop: Optional[AbstractEventLoop] = None,
    ) -> None:
        self.__parser = _Mizu(options)
        if loop:
            self.__parser.set_loop(loop)
    
    def parse(self, text: str) -> str:
        """
        Parse markdown text to html.
        
        Args:
            text (str): Markdown text.
        """
        return self.__parser.parse(text)

    async def aioparse(self, text: str) -> str:
        """
        Parse markdown text to html (async version)
        
        Args:
            text (str): Markdown text
        """
        return await self.__parser.aioparse(text)


from typing import Optional

from .options import Options

import asyncio


class Mizu:
    def __init__(
        self, options: Options = Options()
    ) -> None:
        ...
    
    def set_loop(self, loop: asyncio.AbstractEventLoop) -> None:
        ...

    def parse(self, text: str) -> str:
        ...

    async def aioparse(self, text: str) -> str:
        ...



# mizu - Build documentation

from mizu import parse
from jinja2 import Template, Environment, FileSystemLoader

env = Environment(loader=FileSystemLoader('.'), trim_blocks=False)
template = env.get_template('main.tpl')
with open("main.md", "r") as f:
    raw = f.read()
text = template.render(content=parse(raw))
with open("index.html", "w") as f:
    f.write(text)



import pytest
from mizu import Mizu

import asyncio


@pytest.mark.asyncio
async def test_parse():
    m = Mizu(loop=asyncio.get_running_loop())
    assert await m.aioparse("# hello") == "<h1>hello</h1>\n"